@@ -14,13 +14,23 @@
 
 #include <linux/lkst_private.h>
 
-#define LKST_ETYPE_DEF_DESCRIPTIONS
-#include <linux/lkst_events.h>
-
-#define LKST_ETYPE_DEF_DATATABLE
-#include <linux/lkst_events.h>
-
 #define UNDEF_STR "undefined"
+/* each element of the array is a pair of 
+ description and value of event type.	*/
+
+#define LKST_ETYPE_DEF(event_type, hooktype, mnemonic, event_name, arg_1, arg_2, arg_3, arg_4)    \
+        [(event_type)] = { event_name, 0, { arg_1, arg_2, arg_3, arg_4 }, },
+
+				/* The header of the array. */
+struct LKST_list {
+char*	LKST_event_name;
+int	LKST_filter;
+char*	LKST_inf_args[4];
+} LKST_event_data[] = {
+#include <linux/lkst_etype.h>
+};
+#undef LKST_ETYPE_DEF
+
 
 int lkst_get_status(struct lkst_status_param *sparam)
 {
@@ -31,6 +41,9 @@ int lkst_get_status(struct lkst_status_param *sparam)
 	return retval;
 }
 
+#define GET_STATUS_OR_EXIT(sparam) \
+	if (lkst_get_status(&sparam)<0) {perror("lkst get status"); exit(1);}
+
 /* display as classical format */
 void classical_buffer_list(int cpu)
 {
@@ -50,7 +63,7 @@ void classical_buffer_list(int cpu)
 		fprintf(stderr, "ioctl(LKST_IOC_TRC_STATUS) error: %s\n", strerror(errno));
 		exit(1);
 	}
-	if( cpu != -1 && !((1UL << cpu) & sparam.online_cpu) ) {
+	if( cpu != -1 && !(lkst_cpu_is_online(cpu, sparam)) ) {
 		fprintf(stderr, "error : cannot find cpu %d\n",cpu);
 	}
 	printf(" id\t cpu\tsize\tprev_id\tnext_id\t    readp\t    writep\twrap\n");	
@@ -62,7 +75,7 @@ void classical_buffer_list(int cpu)
 	       0);
 
 
-	for_each_online_cpus( j, sparam.online_cpu) {
+	lkst_for_each_online_cpu(j, sparam) {
 		if (cpu != -1 && cpu != j) continue;
 		lp.cpu = j;
 		lp.listent_num = LKST_BUFFER_TBL_MAX;
@@ -113,19 +126,6 @@ static char * bid2str(char *strbuf, lkst_buffer_id id)
 	return strbuf;
 }
 
-static int lkst_get_cpu_online_map(int fd) 
-{
-	int retval;
-	struct lkst_status_param param;
-
-	retval = ioctl(fd, LKST_IOC_TRC_STATUS, &param); /* trc_status */
-	if (retval<0) {
-		fprintf(stderr, "ioctl(LKST_IOC_TRC_STATUS) error: %s\n", strerror(errno));
-		exit(1);
-	}
-	return param.online_cpu;
-}
-
 static void lkst_buffer_static_list(FILE *fout, int fd, 
 				    struct lkst_status_param *param)
 {
@@ -156,7 +156,7 @@ static int lkst_buffer_list(FILE *fout, int fd, int cpu, int level)
 
 	fprintf(fout,"CPU:%2d  Buffers: %3d  Owner_pid:%5s\n",
 		lp.cpu, lp.buffer_num,
-		(lp.owner==PID_MAX+1)?"--":itosn(buf[0],lp.owner,6));
+		(lp.owner==LKST_OWNER_PID_VOID)?"--":itosn(buf[0],lp.owner,6));
 	
 	if (lp.listent_num < lp.buffer_num) lp.buffer_num = lp.listent_num;
    
@@ -185,26 +185,25 @@ static int lkst_buffer_list(FILE *fout, int fd, int cpu, int level)
 
 void buffer_list(int cpu_id, int level)
 {
-	int cpu;
 	int fd;
-	struct lkst_status_param param={0};
 	fd = open_dev();
 	if(fd <0) {
 		fprintf(stderr,"open() error: %s\n", strerror(errno));
 		exit(1);
 	}
 	if(cpu_id == -1) {
-		lkst_buffer_static_list(stdout,fd,&param);
-	}
-	for(cpu = 0;cpu<LKST_CPU_MAX;cpu++) {
-		if( cpu != cpu_id ){
-			if (cpu_id != -1 || 
-			    !(param.online_cpu & (1UL<<cpu))) continue;
+		int cpu;
+		struct lkst_status_param sparam={0};
+		lkst_buffer_static_list(stdout,fd,&sparam);
+		lkst_for_each_online_cpu(cpu, sparam) {
+			if ( lkst_buffer_list(stdout, fd, cpu, level) < 0) {
+				fprintf(stderr, "ioctl(LKST_IOC_BUFFER_LIST) error: %s\n", strerror(errno));
+				continue;
+			}
 		}
-		
-		if ( lkst_buffer_list(stdout, fd, cpu, level) < 0) {
+	} else {
+		if ( lkst_buffer_list(stdout, fd, cpu_id, level) < 0) {
 			fprintf(stderr, "ioctl(LKST_IOC_BUFFER_LIST) error: %s\n", strerror(errno));
-			continue;
 		}
 	}
 	close(fd);
@@ -233,9 +232,9 @@ void buffer_link(int cpu, lkst_buffer_id id,lkst_buffer_id next)
 			}
 		}
 	}else {
-		int online;
-		online = lkst_get_cpu_online_map(fd);
-		for_each_online_cpus(cpu, online) {
+		struct lkst_status_param sparam;
+		GET_STATUS_OR_EXIT(sparam);
+		lkst_for_each_online_cpu(cpu, sparam) {
 			param.cpu = cpu;		
 			param.id = id ;
 			param.next = next;
@@ -280,9 +279,9 @@ void buffer_create(int cpu, lkst_buffer_id id,
 		       param.cpu, param.id, param.result_size-LKST_BUFFER_MARGIN_BYTE,
 		       LKST_BUFFER_MARGIN_BYTE );
 	}else {
-		int online;
-		online = lkst_get_cpu_online_map(fd);
-		for_each_online_cpus(cpu, online) {
+		struct lkst_status_param sparam;
+		GET_STATUS_OR_EXIT(sparam);
+		lkst_for_each_online_cpu(cpu, sparam) {
 			param.cpu = cpu;
 			param.id = id;
 			param.size = size;
@@ -322,9 +321,9 @@ void buffer_delete(int cpu, lkst_buffer_id id)
 		}
 		printf("Buffer id=%d was deleted.\n", id);
 	}else{
-		int online;
-		online = lkst_get_cpu_online_map(fd);
-		for_each_online_cpus(cpu, online) {
+		struct lkst_status_param sparam;
+		GET_STATUS_OR_EXIT(sparam);
+		lkst_for_each_online_cpu(cpu, sparam) {
 			param.cpu = cpu;
 			param.id = id;
 			retval = ioctl(fd, LKST_IOC_BUFFER_DELETE, &param);	/* buffer_delete */
@@ -367,9 +366,9 @@ void buffer_shift(int cpu)
 		}
 		printf("Currently selected buffer changed on CPU %d\n", cpu);
 	}else {
-		int online;
-		online = lkst_get_cpu_online_map(fd);
-		for_each_online_cpus(cpu, online) {
+		struct lkst_status_param sparam;
+		GET_STATUS_OR_EXIT(sparam);
+		lkst_for_each_online_cpu(cpu, sparam) {
 			retval = lkst_buffer_shift(fd, cpu);	/* buffer_shift */
 			if (retval < 0) {
 				fprintf(stderr, "lkst_buffer_shift() error: %s\n", strerror(errno));
@@ -397,9 +396,9 @@ void buffer_jump(int cpu, lkst_buffer_id dest)
 		}
 		printf("Currently selected buffer changed to %d on CPU %d\n", dest, cpu);
 	} else {
-		int online;
-		online = lkst_get_cpu_online_map(fd);
-		for_each_online_cpus(cpu, online) {
+		struct lkst_status_param sparam;
+		GET_STATUS_OR_EXIT(sparam);
+		lkst_for_each_online_cpu(cpu, sparam) {
 			retval = lkst_buffer_jump(fd, cpu, dest);	/* buffer_shift */
 			if (retval < 0) {
 				fprintf(stderr, "lkst_buffer_jump() error: %s\n", strerror(errno));
@@ -1385,7 +1384,9 @@ static int print_data(struct lkst_arg_print_data *pointpri,int arg_csv_flag)
 			printf(",%02u,%08u", evr[i]->posix.log_processor, evr[i]->posix.log_pid);
 		else
 			printf("\tcpu=%02u, pid=%08u\n", evr[i]->posix.log_processor, evr[i]->posix.log_pid);
-		clock_viewer((unsigned long)evr[i]->posix.log_time.tv_sec, (unsigned long)evr[i]->posix.log_time.tv_nsec,arg_csv_flag);
+		clock_viewer((unsigned long)evr[i]->posix.log_time.tv_sec,
+			     (unsigned long)evr[i]->posix.log_time.tv_nsec,
+			     arg_csv_flag);
 		/* display args_data */
 		for ( j=0; j<4; j++) {
 			if (( LKST_event_data[event_type_num].LKST_inf_args[j] != 0x00) &&
@@ -1440,7 +1441,7 @@ void help_viewer(char* program_name)
 	printf("                         (default : descending sort)\n");
 }
 
-void clock_viewer(unsigned long time_sec, unsigned long time_usec,int arg_csv_form)
+void clock_viewer(unsigned long time_sec, unsigned long time_nsec,int arg_csv_form)
 {
 	struct tm *newtime;
 	time_t    ltime;
@@ -1458,14 +1459,14 @@ void clock_viewer(unsigned long time_sec, unsigned long time_usec,int arg_csv_fo
 			newtime->tm_hour,
 			newtime->tm_min,
 			newtime->tm_sec,
-			time_usec,
+			time_nsec,
 			newtime->tm_year + LKST_LOG_FMT_PRINT_SIZE);
 	}
 	else if ( arg_csv_form & 2)
 	{
-		printf( ",%12lu,%04d",
+		printf( ",%10lu,%09lu",
 			time_sec,
-			time_usec);
+			time_nsec);
 	}
 	else
 	{
@@ -1476,8 +1477,7 @@ void clock_viewer(unsigned long time_sec, unsigned long time_usec,int arg_csv_fo
 			newtime->tm_hour,
 			newtime->tm_min,
 			newtime->tm_sec,
-			time_usec,
+			time_nsec,
 			newtime->tm_year + LKST_LOG_FMT_PRINT_SIZE);
 	}
 }
-
